@@ -12,6 +12,7 @@
 #' @examples
 #'   rickroll_vimeo()
 #'   rickroll_youtube()
+#'   rickroll_channel9() %>% use_start_time("5m03s")
 #'
 NULL
 
@@ -28,3 +29,13 @@ rickroll_vimeo <- function(...){
 rickroll_youtube <- function(...){
   embed_youtube(id = "dQw4w9WgXcQ", ...)
 }
+
+#' @rdname rickroll
+#' @export
+#
+rickroll_channel9 <- function(...){
+  embed_channel9(
+    id = c("Blogs", "Dan", "BlueHat-v7-Katie-Moussouris-interviews-Dan-Kaminsky-on-some-interesting-research-hes-been-doing-late"),
+    ...
+  )
+}
